///////////////////////////////////////////////////////////
// NodeUtils.h
//
// MQSI V2 Node processing utilities

// MQSIX_ATTRIBUTES
// Structure defining MQSI attributes for nodes
typedef struct _MQSIX_ATTRIBUTES {
	CciChar	*attributeName;
	CciChar *attributeValue;
	struct _MQSIX_ATTRIBUTES *pNext;
} MQSIX_ATTRIBUTES;

#define MQSIX_MAX_STRING 128
typedef struct MQSIX_NODE_INFO
{
	CciChar	brokerName[MQSIX_MAX_STRING];
	CciChar	executionGroupName[MQSIX_MAX_STRING];
	CciChar	messageFlowName[MQSIX_MAX_STRING];
	CciChar	queueManagerName[MQSIX_MAX_STRING];
} MQSIX_NODE_INFO;

int mqsixStringCopy(CciChar *source, CciChar *destination, unsigned int iLength);
unsigned int mqsixStringLengthBytes(CciChar *string);
unsigned int mqsixStringLengthCharacters(CciChar *string);
int mqsixStringCompare(CciChar *stringOne, CciChar *stringTwo);
CciChar *mqsixStringDuplicate(CciChar *string);
void mqsixAddAttribute(MQSIX_ATTRIBUTES **pAttribute,
					   CciChar *strName,
					   CciChar *strValue);
void mqsixReleaseAttributes(MQSIX_ATTRIBUTES *pAttributes);
int mqsixGetAttributeName(
	MQSIX_ATTRIBUTES *pAttributes,
	int				index,
	CciChar			*buffer,
	int				bufsize);
int mqsixGetAttribute(
	MQSIX_ATTRIBUTES	*pAttributes,
	CciChar		*attrName,
	CciChar		*buffer,
	int			bufsize);
int mqsixSetAttribute(
	MQSIX_ATTRIBUTES	*pAttributes,
	CciChar		*attrName,
	CciChar		*attrValue);
void mqsixLog(char *szFormat, ...);
char *mqsixElementToString(CciElement *pElement);
CciSize mqsixElementCharValue(CciElement *pElement, CciChar **buffer);
CciSize mqsixElementByteArrayValue(CciElement *pElement, struct CciByteArray *buffer);
void mqsixWalkTree(CciElement *pElement);
void mqsixLogInfo(CciNode *pNode);
void mqsixLogTree(CciElement *pElement);
CciElement *mqsixFindElement(char *path, CciElement *pElement);
CciChar* mqsixASCIIToUnicode(const char* aStr);
char *mqsixUnicodeToASCII(CciChar* ucsString);
void mqsixBrokerInfo(CciNode *nodeObject, MQSIX_NODE_INFO *pNodeInfo);
void mqsixDebugBreak();
CciElement *mqsixNewElement(char *path, CciMessage *pMessage);
#ifdef _WIN32
void mqsixRegisterMessages(HMODULE hModule, char *messageSet);
#endif